summaryrefslogtreecommitdiff
path: root/.dir-locals.el
diff options
context:
space:
mode:
authorZbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl>2018-12-06 15:45:19 +0100
committerYu Watanabe <watanabe.yu+github@gmail.com>2018-12-08 10:14:28 +0100
commitc90ee83400783739ac6df9f12c43bd7074dea8fa (patch)
treec67a2136ed26f8bf8658d85926af6f920f1ab9c0 /.dir-locals.el
parent99b5b0d0eff40adcec746c8f0d6a831d1b972042 (diff)
downloadsystemd-c90ee83400783739ac6df9f12c43bd7074dea8fa.tar.gz
coding style: reduce text width to 109 characters
Patches are shown on github with a fixed width (no matter how wide the window is). When line numbers are high (we have some files with 5 digit line numbers), the diff does not fit, and horizontal scrolling must be used when viewing the patch. This is super annoying. Let's reduce the width a bit. I think 109 is still very wide, but at least the github issue should be alleviated.
Diffstat (limited to '.dir-locals.el')
-rw-r--r--.dir-locals.el6
1 files changed, 3 insertions, 3 deletions
diff --git a/.dir-locals.el b/.dir-locals.el
index e3d01b28a9..676d755231 100644
--- a/.dir-locals.el
+++ b/.dir-locals.el
@@ -2,14 +2,14 @@
; A list of (major-mode . ((var1 . value1) (var2 . value2)))
; Mode can be nil, which gives default values.
; Note that we set a line width of 119 for .c and XML files, but for everything
; else (such as journal catalog files, unit files, README files) we stick to a
; more conservative 79 characters.
; NOTE: If you update this file make sure to update .vimrc and .editorconfig,
; too.
-((c-mode . ((fill-column . 119)
+((c-mode . ((fill-column . 109)
(c-basic-offset . 8)
(eval . (c-set-offset 'substatement-open 0))
(eval . (c-set-offset 'statement-case-open 0))
@@ -17,7 +17,7 @@
(eval . (c-set-offset 'arglist-intro '++))
(eval . (c-set-offset 'arglist-close 0))))
(nxml-mode . ((nxml-child-indent . 2)
- (fill-column . 119)))
+ (fill-column . 109)))
(meson-mode . ((meson-indent-basic . 8)))
(sh-mode . ((sh-basic-offset . 8)
(sh-indentation . 8)))
@@ -2,14 +2,14 @@
; A list of (major-mode . ((var1 . value1) (var2 . value2)))
; Mode can be nil, which gives default values.
-; Note that we set a line width of 119 for .c and XML files, but for everything
+; Note that we set a line width of 109 for .c and XML files, but for everything
; else (such as journal catalog files, unit files, README files) we stick to a
; more conservative 79 characters.